/* Copyright IBM Corp. 2013  All Rights Reserved.                    */
dojo.provide("com.ibm.mashups.enabler.strategy.NavigationDeletionStrategy");

dojo.require("com.ibm.mashups.enabler.strategy.Strategy");

/**
 * Interface that defines the behavior used for page deletion.
 * @ibm-spi
 * @ibm-module Base
 * @since 3.0.0.2
 */
dojo.declare("com.ibm.mashups.enabler.strategy.NavigationDeletionStrategy", com.ibm.mashups.enabler.strategy.Strategy, {
    /**
     * Returns <code>true</code> if the contents associated with the navigation node
     * is to be deleted, <code>false</code> otherwise.<br>
     * Notes:
     * <ul>
     * <li>you must not invoke functions which in turn trigger HTTP GET requests,
     * because this strategy is resolved within the commit function of the navigation
     * model, where only modifying requests are allowed</li>
     * <li>the input navigation node is deleted from the navigation models context,
     * thus it will not be resolved with calling the find function; however, you may
     * invoke getXML on the navigation node to work on its XML representation</li>
     * <li>you may use the default implementation, which will not delete the contents,
     * i.e. not send the HTTP DELETE request to the contents, if the IDs of the
     * navigation node and the contents are identical</li>
     * </ul>
     * @param {com.ibm.mashups.enabler.navigation.NavigationNode} node navigation node to delete
     * @param {String} contentID id of the contents referenced by the navigation node
     * @return {Boolean} <code>true</code> or <code>false</code>
     */
    isDeleteContentByID: function(node, contentID){
        // default implementation that does not delete the contents when the IDs
        // of the navigation node and contents are identical
        return node.getID() != contentID;
    }
});
